==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/BollingerBandsOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialOverlayDescriptionMetadata } from "./FinancialOverlayDescriptionMetadata";
import { BollingerBandsOverlayDescription } from "./BollingerBandsOverlayDescription";
/**
 * @hidden
 */
export let BollingerBandsOverlayDescriptionMetadata = /*@__PURE__*/ (() => {
    class BollingerBandsOverlayDescriptionMetadata extends Base {
        static b(a) {
            if (BollingerBandsOverlayDescriptionMetadata.a == null) {
                BollingerBandsOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BollingerBandsOverlayDescriptionMetadata.c(BollingerBandsOverlayDescriptionMetadata.a);
            }
            if (a.k(BollingerBandsOverlayDescriptionMetadata.a)) {
                return;
            }
            a.ab(BollingerBandsOverlayDescriptionMetadata.a);
        }
        static c(a) {
            FinancialOverlayDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
            a.item("Multiplier", "Number:double");
        }
        static d(a) {
            BollingerBandsOverlayDescriptionMetadata.b(a);
            a.ad("BollingerBandsOverlay", () => new BollingerBandsOverlayDescription());
            a.ac("BollingerBandsOverlay", BollingerBandsOverlayDescriptionMetadata.a);
        }
    }
    BollingerBandsOverlayDescriptionMetadata.$t = markType(BollingerBandsOverlayDescriptionMetadata, 'BollingerBandsOverlayDescriptionMetadata');
    BollingerBandsOverlayDescriptionMetadata.a = null;
    return BollingerBandsOverlayDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/BollingerBandsOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialOverlayDescriptionMetadata } from "./FinancialOverlayDescriptionMetadata";
import { BollingerBandsOverlayDescription } from "./BollingerBandsOverlayDescription";
/**
 * @hidden
 */
export let BollingerBandsOverlayDescriptionMetadata = /*@__PURE__*/ (() => {
    class BollingerBandsOverlayDescriptionMetadata extends Base {
        static b(a) {
            if (BollingerBandsOverlayDescriptionMetadata.a == null) {
                BollingerBandsOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BollingerBandsOverlayDescriptionMetadata.c(BollingerBandsOverlayDescriptionMetadata.a);
            }
            if (a.k(BollingerBandsOverlayDescriptionMetadata.a)) {
                return;
            }
            a.ac(BollingerBandsOverlayDescriptionMetadata.a);
        }
        static c(a) {
            FinancialOverlayDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
            a.item("Multiplier", "Number:double");
        }
        static d(a) {
            BollingerBandsOverlayDescriptionMetadata.b(a);
            a.ae("BollingerBandsOverlay", () => new BollingerBandsOverlayDescription());
            a.ad("BollingerBandsOverlay", BollingerBandsOverlayDescriptionMetadata.a);
        }
    }
    BollingerBandsOverlayDescriptionMetadata.$t = markType(BollingerBandsOverlayDescriptionMetadata, 'BollingerBandsOverlayDescriptionMetadata');
    BollingerBandsOverlayDescriptionMetadata.a = null;
    return BollingerBandsOverlayDescriptionMetadata;
})();
